
package com.salvadorjhai.widgets;

import com.leo.simplearcloader.ArcConfiguration;
import com.leo.simplearcloader.SimpleArcDialog;

import android.content.DialogInterface;
import android.content.DialogInterface.OnDismissListener;
import anywheresoftware.b4a.AbsObjectWrapper;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.ActivityObject;
import anywheresoftware.b4a.BA.Events;
import anywheresoftware.b4a.BA.ShortName;

/**
 * Wrapped Of: https://github.com/generic-leo/SimpleArcLoader Credits to:
 * Prathamesh Sawant (prathamesh.s1989@gmail.com)
 * 
 * Usage:<code>
 * 'create configuration (optional)
 * Dim config As JSArcConfiguration
 * config.Initialize
 * config.LoaderStyle = config.STYLE_COMPLETE_ARC	
 * config.Colors = Array As Int(0xFFE91E63, 0xFF3F51B5, 0xFF9C27B0, 0xFFFFC107, 0xFFF44336, 0xFF4CAF50, 0xFF03A9F4)
 * config.Text = "Loading..Please wait..."
 * 
 * 'create, initialize JSSimpleArcDialog, call .Show method.
 * Dim dlg As JSSimpleArcDialog
 * dlg.Initialize("dlg")
 * dlg.Show2(config, True)			
 * </code>
 */

@ShortName("JSSimpleArcDialog")
@Events(values = { "OnDismiss" })
@ActivityObject
public class JSSimpleArcDialog extends AbsObjectWrapper<SimpleArcDialog> {

	public JSSimpleArcDialog() {
	}

	private String mEventName = "";
	private BA ba = null;

	/**
	 * Initialize JSSimpleArcDialog
	 * 
	 * @param ba
	 * @param eventName
	 */
	public void Initialize(final BA ba, String eventName) {
		this.ba = ba;
		this.mEventName = eventName;

		// SimpleArcDialog dlg = new SimpleArcDialog(ba.context, new
		// ArcConfiguration(ba.context));
		// dlg.setCancelable(true);

		this.setObject(new SimpleArcDialog(ba.context, new ArcConfiguration(ba.context)));

		final BA b = ba;
		this.getObjectOrNull().setOnDismissListener(new OnDismissListener() {
			@Override
			public void onDismiss(DialogInterface arg0) {
				String event = mEventName + "_OnDismiss";
				// b.raiseEventFromUI(this, event.toLowerCase());
				b.raiseEventFromDifferentThread(this, null, 0, event.toLowerCase(), false, null);
			}
		});
	}

	/**
	 * Initialize JSSimpleArcDialog
	 * 
	 * @param ba
	 * @param eventName
	 *            event name
	 * @param config
	 *            JSArcConfiguration
	 */
	public void Initialize2(final BA ba, String eventName, JSArcConfiguration config) {
		this.ba = ba;
		this.mEventName = eventName;

		this.setObject(new SimpleArcDialog(ba.context, config.getObjectOrNull()));

		final BA b = ba;
		this.getObjectOrNull().setOnDismissListener(new OnDismissListener() {
			@Override
			public void onDismiss(DialogInterface arg0) {
				String event = mEventName + "_OnDismiss";
				// b.raiseEventFromUI(this, event.toLowerCase());
				b.raiseEventFromDifferentThread(this, null, 0, event.toLowerCase(), false, null);
			}
		});
	}

	/**
	 * Show JSSimpleArcDialog with default configuration
	 */
	public void Show(boolean Cancelable) {
		try {
			this.getObjectOrNull().setCancelable(Cancelable);
			this.getObjectOrNull().setConfiguration(new ArcConfiguration(this.ba.context));
			this.getObjectOrNull().show();
		} catch (Exception e) {
			BA.LogError(e.getMessage());
		}
	}

	/**
	 * Show JSSimpleArcDialog with custom configuration
	 * 
	 * @param config
	 *            JSArcConfiguration
	 * @param Cancelable
	 */
	public void Show2(JSArcConfiguration config, boolean Cancelable) {
		try {
			this.getObjectOrNull().setCancelable(Cancelable);
			this.getObjectOrNull().setConfiguration(config.getObjectOrNull());
			this.getObjectOrNull().show();
		} catch (Exception e) {
			BA.LogError(e.getMessage());
		}
	}

	/**
	 * Dismiss ArcDialog
	 */
	public void Dismiss() {
		this.getObjectOrNull().dismiss();
	}

	/**
	 * Check if dialog is showing
	 * 
	 * @return IsShowing
	 */
	public boolean IsShowing() {
		return this.getObjectOrNull().isShowing();
	}

}
