/*
 * Materials:
 * https://github.com/generic-leo/SimpleArcLoader
 * 
 * r2	- implemented designer custom view (JSSimpleArcLoader)
 * r1	- JSSimpleArcDialog
 * 		- JSSimpleArcLoader
 * 		- JSArcConfiguration
 * 
 */

package com.salvadorjhai.widgets;

import com.leo.simplearcloader.ArcConfiguration;
import com.leo.simplearcloader.SimpleArcLoader;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.keywords.Common.DesignerCustomView;
import anywheresoftware.b4a.objects.CustomViewWrapper;
import anywheresoftware.b4a.objects.LabelWrapper;
import anywheresoftware.b4a.objects.PanelWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.objects.collections.Map;

/**
 * Wrapped Of: https://github.com/generic-leo/SimpleArcLoader 
 * Credits to: Prathamesh Sawant (prathamesh.s1989@gmail.com)
 * 
 * Usage 1:<code>
 * 'create, initialize and add JSSimpleArcLoader on your activity
 * Dim arc1 As JSSimpleArcLoader
 * arc1.Initialize
 * Activity.AddView(arc1, left, top, width, height)
 * 
 * 'you can also set custom configuration
 * Dim config As JSArcConfiguration
 * config.Initialize
 * config.LoaderStyle = config.STYLE_COMPLETE_ARC	
 * config.Colors = Array As Int(0xFFE91E63, 0xFF3F51B5, 0xFF9C27B0)
 * arc1.refreshArcLoaderDrawable(config)
 * </code>
 * 
 * Usage 2:<code>
 * Use Custom Designer and drag JSSimpleArcLoader on your layout.
 * </code>
 * 
 */
@ShortName("JSSimpleArcLoader")
@Version(0.3f)
@Author("salvadorjhai")
@DependsOn(values = { "JSSimpleArcLoader.aar" })
public class JSSimpleArcLoader extends ViewWrapper<SimpleArcLoader> implements DesignerCustomView {
	
	private BA mBA = null;
	private String mEventName = "";
	
	/**
	 * Instantiates a new JS simple arc loader.
	 */
	public JSSimpleArcLoader() {
	}

	public void Initialize(BA ba) {
		_initialize(ba, null, "");
	}
  
	@Override
	@BA.Hide
	public void _initialize(BA ba, Object paramObject, String eventName) {
		innerInitialize(ba, eventName, false);
	}
	
	@Override
	@BA.Hide
	public void innerInitialize(final BA ba, final String eventName, boolean keepOldObject) {
		this.mBA = ba;
		this.mEventName = eventName;
		
		try {
			// set object and props
			if (!keepOldObject) {
				this.setObject(new SimpleArcLoader(ba.context));
				this.getObjectOrNull().refreshArcLoaderDrawable(new ArcConfiguration(ba.context));
			}
			
			// Inner Initialize
		    super.innerInitialize(ba, eventName, true);
			
		} catch (Exception e) {
			ba.setLastException(e);
			BA.LogError(e.getMessage());
		}
	}
	
	@Override
	public void DesignerCreateView(PanelWrapper paramPanelWrapper, LabelWrapper paramLabelWrapper, Map paramMap) {
		CustomViewWrapper.replaceBaseWithView2(paramPanelWrapper, this.getObjectOrNull());
	}

	/**
	 * Start ArcLoader animation.
	 */
	public void Start() {
		try {
			this.getObjectOrNull().start();
		} catch (Exception e) {
			ba.setLastException(e);
			BA.LogError(e.getMessage());
		}
	}

	/**
	 * Stop ArcLoader animation.
	 */
	public void Stop() {
		try {
			this.getObjectOrNull().stop();
		} catch (Exception e) {
			ba.setLastException(e);
			BA.LogError(e.getMessage());
		}
	}

	/**
	 * Checks if ArcLoader is running.
	 *
	 * @return true, if successful
	 */
	public boolean IsRunning() {
		try {
			return this.getObjectOrNull().isRunning();
		} catch (Exception e) {
			ba.setLastException(e);
			BA.LogError(e.getMessage());
		}
		return false;
	}

	/**
	 * Refresh ArcLoader configuration.
	 *
	 * @param configuration
	 *            JSArcConfiguration
	 */
	public void refreshArcLoaderDrawable(JSArcConfiguration configuration) {
		try {
			this.getObjectOrNull().refreshArcLoaderDrawable(configuration.getObjectOrNull());
		} catch (Exception e) {
			ba.setLastException(e);
			BA.LogError(e.getMessage());
		}
	}

}
